@@ -1,7 +1,10 @@
 import os
 import logging
-logger = logging.getLogger('hidtools')
+
+from ._version import __version__
+
+logger = logging.getLogger("hidtools")
 # If HID_DEBUG is set, set the base logger to verbose, triggering all child
 # loggers to become verbose too.
-if os.environ.get('HID_DEBUG', False):
+if os.environ.get("HID_DEBUG", False):
     logger.setLevel(logging.DEBUG)
